##
##  lcms.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_lcms2  2.16
%define       V_lcms1  1.19

#   package information
Name:         lcms
Summary:      Little Color Management System Library
URL:          http://www.littlecms.com/
Vendor:       Marti Maria
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Graphics
License:      MIT
Version:      %{V_lcms2}
Release:      20231205

#   list of sources
Source0:      http://download.sourceforge.net/lcms/lcms-%{V_lcms1}.tar.gz
Source1:      http://download.sourceforge.net/lcms/lcms2-%{V_lcms2}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  jpeg, tiff, zlib
PreReq:       jpeg, tiff, zlib

%description
   Little CMS is a small-footprint, speed optimized color management
   system library.

%track
    prog lcms:lcms2 = {
        version   = %{V_lcms2}
        url       = http://sourceforge.net/projects/lcms/files/lcms/
        regex     = lcms2-(\d+(\.\d+)+[a-z]?)\.tar\.gz
    }
    prog lcms:lcms1 = {
        disabled
        comment   = "no more versions 1.x are released"
        version   = %{V_lcms1}
        url       = http://sourceforge.net/projects/lcms/files/lcms/
        regex     = lcms-(\d+(\.\d+)+[a-z]?)\.tar\.gz
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1

%build
    ( cd lcms-%{V_lcms1}
      CC="%{l_cc}" \
      CFLAGS="%{l_cflags -O}" \
      CPPFLAGS="%{l_cppflags tiff .}" \
      LDFLAGS="%{l_ldflags}" \
      GREP="grep" \
      ./configure \
          --prefix=%{l_prefix} \
          --mandir=%{l_prefix}/man \
          --disable-shared
      %{l_make} %{l_mflags -O}
    ) || exit $?
    ( cd lcms2-%{V_lcms2}
      CC="%{l_cc}" \
      CFLAGS="%{l_cflags -O}" \
      CPPFLAGS="%{l_cppflags tiff .}" \
      LDFLAGS="%{l_ldflags}" \
      GREP="grep" \
      ./configure \
          --prefix=%{l_prefix} \
          --mandir=%{l_prefix}/man \
          --disable-shared
      %{l_make} %{l_mflags -O}
    ) || exit $?

%install
    ( cd lcms-%{V_lcms1}
      %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    ) || exit $?
    ( cd lcms2-%{V_lcms2}
      %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    ) || exit $?
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

